@@ -1,7 +1,7 @@
 """The UML Modeling Language module is the entrypoint for UML related
 assets."""
 
-from typing import Iterable
+from collections.abc import Iterable
 
 from gaphor.abc import ModelingLanguage
 from gaphor.core import gettext
@@ -12,6 +12,7 @@ from gaphor.diagram.diagramtoolbox import (
 )
 from gaphor.UML import diagramitems, uml
 from gaphor.UML.toolbox import uml_diagram_types, uml_element_types, uml_toolbox_actions
+from gaphor.UML.treemodel import TreeModel
 
 
 class UMLModelingLanguage(ModelingLanguage):
@@ -32,5 +33,10 @@ class UMLModelingLanguage(ModelingLanguage):
     def element_types(self) -> Iterable[ElementCreateInfo]:
         yield from uml_element_types
 
-    def lookup_element(self, name):
+    @property
+    def model_browser_model(self) -> type[TreeModel]:
+        return TreeModel
+
+    def lookup_element(self, name, ns=None):
+        assert ns in ("UML", None)
         return getattr(uml, name, None) or getattr(diagramitems, name, None)
